<?php

namespace Drupal\content_feedback\Controller;

use Drupal\content_feedback\Form\ContentFeedbackClass;
use Drupal\Core\Controller\ControllerBase;
use Drupal\Core\Link;
use Drupal\Core\Datetime\DrupalDateTime;

/**
 * Extends ControllerBase.
 *
 * @inheritdoc
 */
class AdminFeedbackController extends ControllerBase {

  /**
   * Content Feedbacks Admin Page.
   *
   * @return array
   *   Returns renderable array that display all content feedbacks.
   */
  public function content() {
    $header = [
      [
        'data' => $this->t('Date'),
        'field' => 'updated',
        'sort' => 'desc',
      ],
      [
        'data' => $this->t('User'),
        'field' => 'name',
        'sort' => 'asc',
      ],
      'email' => $this->t('Email'),
      'path' => $this->t('Location'),
      'ipaddress' => $this->t('IP Address'),
      'message' => $this->t('Feedback'),
      'operations' => $this->t('Actions'),
    ];

    $rows = [];

    if (ContentFeedbackClass::getAll($header)) {
      foreach (ContentFeedbackClass::getAll($header) as $id => $content) {
        $actionLink = [];

        $actionLink[] = Link::createFromRoute(
          $this->t('Edit'),
          'content_feedback_edit.form', ['id' => $id]
        )->toRenderable();
        $actionLink[] = Link::createFromRoute(
          $this->t('Delete'),
          'content_feedback_delete.form', ['id' => $id]
        )->toRenderable();

        $actionLinks = render($actionLink);

        $submitDate = DrupalDateTime::createFromTimestamp($content->updated,
          new \DateTimeZone(drupal_get_user_timezone())
        );

        $status = ($content->status == 1) ? 'open' : 'processed';

        $rows[$status][] = [
          'data' => [
            $submitDate->format('m/d/Y - H:i'),
            $content->name,
            $content->email,
            $content->path,
            $content->ipaddress,
            $content->message,
            $actionLinks,
          ],
        ];
      }
      if (isset($rows['open']) && !empty($rows['open'])) {
        $tableOpen = [
          '#type' => 'table',
          '#header' => $header,
          '#rows' => $rows['open'],
          '#attributes' => [
            'id' => 'op-fb-table',
          ],
        ];
        $openedFeedbacks = render($tableOpen);
      }
      else {
        $openedFeedbacks = "There are no Open feedback entries.";
      }

      if (isset($rows['processed']) && !empty($rows['processed'])) {
        $tableProcessed = [
          '#type' => 'table',
          '#header' => $header,
          '#rows' => $rows['processed'],
          '#attributes' => [
            'id' => 'pr-fb-table',
          ],
        ];
        $resolvedFeedbacks = render($tableProcessed);
      }
      else {
        $resolvedFeedbacks = 'There are no processed content feedback entries.';
      }

      $content_feedback_list = [
        '#type' => 'markup',
        '#markup' => '<h3>Open Content Feedbacks</h3>' .
        $openedFeedbacks .
        '<h3>Resolved Content Feedbacks</h3>' . $resolvedFeedbacks,
      ];
    }
    else {
      $content_feedback_list = [
        '#type' => 'markup',
        '#markup' => '<p>No Content Feedbacks Found</p>',
      ];
    }

    return $content_feedback_list;
  }

}
