<?php

namespace Drupal\content_feedback\Form;

use Drupal\Core\Access\AccessResult;
use Drupal\Core\Session\AccountInterface;
use Drupal\Core\Form\FormBase;
use Drupal\Core\Form\FormStateInterface;
use Drupal\Core\Url;
use Symfony\Component\HttpFoundation;
use Symfony\Component\HttpFoundation\Request;

/**
 * Extends FormBase.
 *
 * @inheritdoc
 */
class AddContentFeedback extends FormBase {

  /**
   * {@inheritdoc}
   */
  public function getFormId() {
    return 'content_feedback_form';
  }

  /**
   * {@inheritdoc}
   */
  public function buildForm(array $form, FormStateInterface $form_state) {
    $name = \Drupal::config('content_feedback.settings')->get('name');
    $email = \Drupal::config('content_feedback.settings')->get('email');

    $form['name'] = [
      '#type' => 'textfield',
      '#title' => $this->t('Name'),
      '#default_value' => $this->currentUser()->getAccountName(),
      '#required' => ($name['required'] === 'required') ? TRUE : FALSE,
    ];

    $form['email'] = [
      '#type' => 'email',
      '#title' => $this->t('Email'),
      '#default_value' => $this->currentUser()->getEmail(),
      '#required' => ($email['required'] === 'required') ? TRUE : FALSE,
    ];

    $form['message'] = [
      '#type' => 'textarea',
      '#title' => $this->t('Do you have any suggestions to make this page better ?'),
      '#rows' => 3,
      '#required' => TRUE,
    ];

    $form['path'] = [
      '#type' => 'hidden',
      '#title' => $this->t('Feedback Page'),
      '#value' => Request::createFromGlobals()->server->get('HTTP_REFERER'),
      '#required' => TRUE,
    ];

    $form['ipaddress'] = [
      '#type' => 'hidden',
      '#title' => $this->t('IP Address'),
      '#value' => \Drupal::request()->getClientIp(),
      '#required' => TRUE,
    ];

    $form['actions'] = [
      '#type' => 'actions',
    ];

    $form['actions']['submit'] = [
      '#type' => 'submit',
      '#value' => $this->t('Send Feedback'),
    ];

    if ($name['show'] === 0) {
      unset($form['name']);
    }

    if ($email['show'] === 0) {
      unset($form['email']);
    }

    return $form;
  }

  /**
   * Form Submission.
   *
   * @inheritdoc
   */
  public function submitForm(array &$form, FormStateInterface $form_state) {
    $url = Url::fromUri(Request::createFromGlobals()->server->get('HTTP_REFERER'));
    $values = $form_state->getValues();
    $name = isset($values['name']) ? $values['name'] : NULL;
    $email = isset($values['email']) ? $values['email'] : NULL;
    $message = $values['message'];
    $path = $values['path'];
    $ipaddress = $values['ipaddress'];
    $timestamp = time();
    ContentFeedbackClass::add($name, $email, $message, $path, $ipaddress, $timestamp);
    $form_state->setRedirectUrl($url);
    drupal_set_message($this->t('Your Content Feedback has been submitted'));
  }

}
