<?php

namespace Drupal\content_feedback\Form;

use Drupal\Core\Form\ConfigFormBase;
use Drupal\Core\Form\FormStateInterface;
use Drupal\node\Entity\NodeType;

/**
 * Form for Content Feedback settings.
 */
class ContentFeedbackSettingsForm extends ConfigFormBase {

  /**
   * {@inheritdoc}
   */
  public function getFormId() {
    return 'content_feedback_settings';
  }

  /**
   * {@inheritdoc}
   */
  protected function getEditableConfigNames() {
    return ['content_feedback.settings'];
  }

  /**
   * {@inheritdoc}
   */
  public function buildForm(array $form, FormStateInterface $form_state) {
    $config = $this->config('content_feedback.settings');
    // Get List Of Content Types.
  	$node_type = node_type_get_names();
	  $form['content_types'] = [
		  '#type' => 'checkboxes',
      '#options' => $node_type,
      '#title' => $this->t('List of content types in which you want content feedback'),
		  '#description' => $this->t('Select Content type for which you want to display the content feedback.'),
		  '#default_value' => is_array($config->get('content_types')) ? array_filter($config->get('content_types')) : [NULL],
	 ];

    $form['name'] = [
      '#type' => 'checkboxes',
      '#title' => $this->t('Name'),
      '#options' => ['show' => $this->t('Show'), 'required' => $this->t('Required')],
      '#default_value' => !empty($config->get('name')) ? $config->get('name') : ['show']
    ];

    $form['email'] = [
      '#type' => 'checkboxes',
      '#title' => $this->t('Email'),
      '#options' => ['show' => $this->t('Show'), 'required' => $this->t('Required')],
      '#default_value' => !empty($config->get('email')) ? $config->get('email') : ['show']
    ];

    return parent::buildForm($form, $form_state);
  }

  /**
   * {@inheritdoc}
   */
  public function submitForm(array &$form, FormStateInterface $form_state) {
    $config = $this->config('content_feedback.settings');
    $config->set('content_types', $form_state->getValue('content_types'));
    $config->set('name', $form_state->getValue('name'));
    $config->set('email', $form_state->getValue('email'));
    $config->save();

    parent::submitForm($form, $form_state);
  }

}
